summaryrefslogtreecommitdiffhomepage
path: root/runsc/boot/config.go
diff options
context:
space:
mode:
Diffstat (limited to 'runsc/boot/config.go')
-rw-r--r--runsc/boot/config.go9
1 files changed, 5 insertions, 4 deletions
diff --git a/runsc/boot/config.go b/runsc/boot/config.go
index 87a47dd0b..28a1600cd 100644
--- a/runsc/boot/config.go
+++ b/runsc/boot/config.go
@@ -214,10 +214,11 @@ type Config struct {
// SIGUSR2(12) to troubleshoot hangs. -1 disables it.
PanicSignal int
- // TestOnlyAllowRunAsCurrentUser should only be used in tests. It
- // allows runsc to start the sandbox process as the current user if we
- // do not have capability to set uid/gid to another user.
- TestOnlyAllowRunAsCurrentUser bool
+ // TestOnlyAllowRunAsCurrentUserWithoutChroot should only be used in
+ // tests. It allows runsc to start the sandbox process as the current
+ // user, and without chrooting the sandbox process. This can be
+ // necessary in test environments that have limited capabilities.
+ TestOnlyAllowRunAsCurrentUserWithoutChroot bool
}
// ToFlags returns a slice of flags that correspond to the given Config.